@@ -268,7 +268,7 @@ class ArgParseConfigLoader(FileConfigLoader):
             if isinstance(v, dict):
                 self.search(v, [*paths, k])
             else:
-                self.parser.add_argument("--{}".format(".".join([*paths, k])), action=self.action, default=v, type=type(v))
+                self.parser.add_argument("--{}".format(".".join([*paths, k])), action=self.action, default=v, type=type(v), metavar=str(v))
     def load(self) -> typing.Any:
         self.search(self.filtered_namespace)
         log_loaded(self.__class__, self.path)
